@@ -116,6 +116,10 @@ def ImportCoco(path, path_to_images=None, name=None):
     df.index.name = "id"
     df.annotated = 1
 
+    # Fill na values with empty strings which resolved some errors when
+    # working with images that don't have any annotations
+    df.fillna("", inplace=True)
+
     # These should be strings
     df.cat_id = df.cat_id.astype(str)
 
@@ -371,7 +375,7 @@ def ImportYoloV5(
                         row["cat_id"] = cat_id
                         row["cat_name"] = GetCatNameFromId(cat_id, cat_names)
 
-                        d[row_id] = row
+                        d[row_id] = dict(row)
                         row_id += 1
                         # Copy the image data to use for the next row
                     else:
